==> certificatetransparency-android-1.0.0-sources.jar: com/appmattus/certificatetransparency/chaincleaner/AndroidCertificateChainCleaner.kt <==
/*
 * Copyright 2021 Appmattus Limited
 * Copyright 2019 Babylon Partners Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * File modified by Appmattus Limited
 * See: https://github.com/appmattus/certificatetransparency/compare/e3d469df9be35bcbf0f564d32ca74af4e5ca4ae5...main
 */

package com.appmattus.certificatetransparency.chaincleaner

import android.net.http.X509TrustManagerExtensions
import java.security.cert.X509Certificate
import javax.net.ssl.X509TrustManager

internal class AndroidCertificateChainCleaner(
    private val extensions: X509TrustManagerExtensions
) : CertificateChainCleaner {

    override fun clean(chain: List<X509Certificate>, hostname: String): List<X509Certificate> {
        return extensions.checkServerTrusted(chain.toTypedArray(), "RSA", hostname)
    }

    class Factory : CertificateChainCleanerFactory {
        override fun get(trustManager: X509TrustManager) = AndroidCertificateChainCleaner(X509TrustManagerExtensions(trustManager))
    }
}

==> certificatetransparency-android-2.0.1-sources.jar: com/appmattus/certificatetransparency/chaincleaner/AndroidCertificateChainCleaner.kt <==
/*
 * Copyright 2021-2023 Appmattus Limited
 * Copyright 2019 Babylon Partners Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * File modified by Appmattus Limited
 * See: https://github.com/appmattus/certificatetransparency/compare/e3d469df9be35bcbf0f564d32ca74af4e5ca4ae5...main
 */

package com.appmattus.certificatetransparency.chaincleaner

import android.net.http.X509TrustManagerExtensions
import java.security.cert.X509Certificate
import javax.net.ssl.X509TrustManager

internal class AndroidCertificateChainCleaner(
    private val extensions: X509TrustManagerExtensions
) : CertificateChainCleaner {

    override fun clean(chain: List<X509Certificate>, hostname: String): List<X509Certificate> {
        return extensions.checkServerTrusted(chain.toTypedArray(), "RSA", hostname)
    }

    class Factory : CertificateChainCleanerFactory {
        override fun get(trustManager: X509TrustManager) = AndroidCertificateChainCleaner(
            X509TrustManagerExtensions(trustManager)
        )
    }
}
